library(lme4)
showClass('pdNatural')
data(Oxboys)
m1 <- pdNatural(~ 1)
m1
isInitialized(m1)   # should return FALSE
## These method calls should produce error messages
try(pdMatrix(m1))
try(pdFactor(m1))
try(as(m1, 'matrix'))
formula(m1)
try(coef(m1))
try(corMatrix(m1))
try(dim(m1))
## Initialize the coefficients - this does initialize the matrix
coef(m1) <- 1.01
pdMatrix(m1)
pdFactor(m1)
as(m1, 'matrix')
formula(m1)
coef(m1)
corMatrix(m1)
dim(m1)
## Initialize from a model matrix
#m2 <- pdNatural(~ 1)
#coef(m2) <- rnorm(1)
#try(as(m2, 'matrix') <- crossprod(model.matrix(height ~ 1, Oxboys)))
#pdMatrix(m2)
#pdFactor(m2)
#as(m2, 'matrix')
#formula(m2)
#coef(m2)
#corMatrix(m2)
#dim(m2)
## Check for dimensions > 1
m3 <- pdNatural(~ age)
coef(m3) <- rnorm(3)
#try(as(m3, 'matrix') <- crossprod(model.matrix(formula(m3), Oxboys)))
pdMatrix(m3)
pdFactor(m3)
as(m3, 'matrix')
formula(m3)
coef(m3)
corMatrix(m3)
dim(m3)
#try(LMEgradient(m3, diag(2), nlev = 4))
#try(EMupdate(m3, 4) <- diag(2))
#show(m3)
#print(m3)
